@@ -3,7 +3,7 @@ require LWP::UserAgent;
 
 use vars qw(@ISA $VERSION);
 @ISA = qw(LWP::UserAgent);
-$VERSION = '1.08';
+$VERSION = '1.09';
 
 require HTTP::Request;
 require HTTP::Response;
@@ -22,7 +22,7 @@ sub new {
     my $resolver          = delete $opts{resolver};
     my $paranoid_proxy    = delete $opts{paranoid_proxy};
     $opts{timeout}      ||= 15;
-
+ 
     my $self = LWP::UserAgent->new( %opts );
 
     $self->{'blocked_hosts'}     = $blocked_hosts;
@@ -567,6 +567,10 @@ http://brad.livejournal.com/2409049.html
 https://github.com/collectiveintel/LWPx-ParanoidAgent
 http://search.cpan.org/dist/LWPx-ParanoidAgent
 
+=head1 ISSUES
+
+Report issues: https://github.com/collectiveintel/LWPx-ParanoidAgent/issues
+
 =head1 WARRANTY
 
 This module is supplied "as-is" and comes with no warranty, expressed
